# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/GUI2.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.setEnabled(True)
        MainWindow.resize(800, 480)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QtCore.QSize(800, 480))
        MainWindow.setMaximumSize(QtCore.QSize(800, 480))
        MainWindow.setStyleSheet("")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setStyleSheet("font: \"Bahnschrift Light\";\n"
"background-color: rgb(255, 255, 255);")
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_24 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_24.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_24.setSpacing(0)
        self.verticalLayout_24.setObjectName("verticalLayout_24")
        self.verticalLayout_23 = QtWidgets.QVBoxLayout()
        self.verticalLayout_23.setSpacing(0)
        self.verticalLayout_23.setObjectName("verticalLayout_23")
        self.widget = QtWidgets.QWidget(self.centralwidget)
        self.widget.setStyleSheet("background-color: rgba(240, 240, 240, 1);border-bottom: 1px solid black;")
        self.widget.setObjectName("widget")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_9.setSpacing(0)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setContentsMargins(15, 10, -1, 10)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.widget_title = QtWidgets.QStackedWidget(self.widget)
        self.widget_title.setStyleSheet("border: none;")
        self.widget_title.setObjectName("widget_title")
        self.page_3 = QtWidgets.QWidget()
        self.page_3.setObjectName("page_3")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.page_3)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.lbl_page = QtWidgets.QLabel(self.page_3)
        self.lbl_page.setStyleSheet("font: 23px \"Bahnschrift SemiBold\"; border: none;")
        self.lbl_page.setObjectName("lbl_page")
        self.verticalLayout_2.addWidget(self.lbl_page)
        self.widget_title.addWidget(self.page_3)
        self.page_4 = QtWidgets.QWidget()
        self.page_4.setObjectName("page_4")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.page_4)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.lbl_page_2 = QtWidgets.QLabel(self.page_4)
        self.lbl_page_2.setStyleSheet("font: 23px \"Bahnschrift SemiBold\"; border: none;")
        self.lbl_page_2.setObjectName("lbl_page_2")
        self.verticalLayout_3.addWidget(self.lbl_page_2)
        self.widget_title.addWidget(self.page_4)
        self.page_5 = QtWidgets.QWidget()
        self.page_5.setObjectName("page_5")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.page_5)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.lbl_page_3 = QtWidgets.QLabel(self.page_5)
        self.lbl_page_3.setStyleSheet("font: 23px \"Bahnschrift SemiBold\"; border: none;")
        self.lbl_page_3.setObjectName("lbl_page_3")
        self.verticalLayout_4.addWidget(self.lbl_page_3)
        self.widget_title.addWidget(self.page_5)
        self.page_8 = QtWidgets.QWidget()
        self.page_8.setObjectName("page_8")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.page_8)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.lbl_page_4 = QtWidgets.QLabel(self.page_8)
        self.lbl_page_4.setStyleSheet("font: 23px \"Bahnschrift SemiBold\"; border: none;")
        self.lbl_page_4.setObjectName("lbl_page_4")
        self.verticalLayout_10.addWidget(self.lbl_page_4)
        self.widget_title.addWidget(self.page_8)
        self.horizontalLayout_10.addWidget(self.widget_title)
        self.horizontalLayout_9.addLayout(self.horizontalLayout_10)
        self.verticalLayout_23.addWidget(self.widget)
        self.widget_14 = QtWidgets.QWidget(self.centralwidget)
        self.widget_14.setMaximumSize(QtCore.QSize(1000, 500))
        self.widget_14.setObjectName("widget_14")
        self.verticalLayout_21 = QtWidgets.QVBoxLayout(self.widget_14)
        self.verticalLayout_21.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_21.setObjectName("verticalLayout_21")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setContentsMargins(5, -1, 5, -1)
        self.horizontalLayout_11.setSpacing(0)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.btn_move_left = QtWidgets.QPushButton(self.widget_14)
        self.btn_move_left.setAutoFillBackground(False)
        self.btn_move_left.setStyleSheet("background-color: rgba(255, 255, 255, 0);")
        self.btn_move_left.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("../ast_monitor/icons/arrow_left.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_move_left.setIcon(icon)
        self.btn_move_left.setIconSize(QtCore.QSize(30, 50))
        self.btn_move_left.setCheckable(False)
        self.btn_move_left.setAutoRepeat(False)
        self.btn_move_left.setAutoExclusive(False)
        self.btn_move_left.setAutoDefault(False)
        self.btn_move_left.setDefault(False)
        self.btn_move_left.setFlat(False)
        self.btn_move_left.setObjectName("btn_move_left")
        self.horizontalLayout_11.addWidget(self.btn_move_left)
        self.stackedWidget = QtWidgets.QStackedWidget(self.widget_14)
        self.stackedWidget.setObjectName("stackedWidget")
        self.page_main = QtWidgets.QWidget()
        self.page_main.setObjectName("page_main")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.page_main)
        self.verticalLayout_12.setContentsMargins(60, 15, 60, 15)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.gridLayout_3.setContentsMargins(0, -1, -1, -1)
        self.gridLayout_3.setSpacing(0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.widget_11 = QtWidgets.QWidget(self.page_main)
        self.widget_11.setMinimumSize(QtCore.QSize(177, 100))
        self.widget_11.setStyleSheet("background-color: rgb(248, 248, 248);\n"
"border: 2px solid black;\n"
"border-radius: 5px;")
        self.widget_11.setObjectName("widget_11")
        self.verticalLayout_17 = QtWidgets.QVBoxLayout(self.widget_11)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.img_distance = QtWidgets.QLabel(self.widget_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(50)
        sizePolicy.setVerticalStretch(40)
        sizePolicy.setHeightForWidth(self.img_distance.sizePolicy().hasHeightForWidth())
        self.img_distance.setSizePolicy(sizePolicy)
        self.img_distance.setMinimumSize(QtCore.QSize(45, 35))
        self.img_distance.setMaximumSize(QtCore.QSize(45, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setItalic(False)
        self.img_distance.setFont(font)
        self.img_distance.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.img_distance.setStyleSheet("border: none")
        self.img_distance.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.img_distance.setFrameShadow(QtWidgets.QFrame.Plain)
        self.img_distance.setText("")
        self.img_distance.setPixmap(QtGui.QPixmap("../ast_monitor/icons/distance.svg"))
        self.img_distance.setScaledContents(True)
        self.img_distance.setAlignment(QtCore.Qt.AlignCenter)
        self.img_distance.setObjectName("img_distance")
        self.horizontalLayout_16.addWidget(self.img_distance)
        self.verticalLayout_17.addLayout(self.horizontalLayout_16)
        self.lbl_distance = QtWidgets.QLabel(self.widget_11)
        self.lbl_distance.setMaximumSize(QtCore.QSize(800, 480))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_distance.setFont(font)
        self.lbl_distance.setStyleSheet("border: 0px;")
        self.lbl_distance.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_distance.setObjectName("lbl_distance")
        self.verticalLayout_17.addWidget(self.lbl_distance)
        self.gridLayout_3.addWidget(self.widget_11, 0, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_3.addItem(spacerItem, 2, 0, 1, 1)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.widget_8 = QtWidgets.QWidget(self.page_main)
        self.widget_8.setMinimumSize(QtCore.QSize(177, 100))
        self.widget_8.setMaximumSize(QtCore.QSize(177, 16777215))
        self.widget_8.setStyleSheet("background-color: rgb(248, 248, 248);\n"
"border: 2px solid black;\n"
"border-radius: 5px;")
        self.widget_8.setObjectName("widget_8")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.widget_8)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.img_speed = QtWidgets.QLabel(self.widget_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(40)
        sizePolicy.setHeightForWidth(self.img_speed.sizePolicy().hasHeightForWidth())
        self.img_speed.setSizePolicy(sizePolicy)
        self.img_speed.setMinimumSize(QtCore.QSize(45, 35))
        self.img_speed.setMaximumSize(QtCore.QSize(45, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setItalic(False)
        self.img_speed.setFont(font)
        self.img_speed.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.img_speed.setStyleSheet("border: none")
        self.img_speed.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.img_speed.setFrameShadow(QtWidgets.QFrame.Plain)
        self.img_speed.setText("")
        self.img_speed.setPixmap(QtGui.QPixmap("../ast_monitor/icons/speed.svg"))
        self.img_speed.setScaledContents(True)
        self.img_speed.setAlignment(QtCore.Qt.AlignCenter)
        self.img_speed.setObjectName("img_speed")
        self.horizontalLayout_13.addWidget(self.img_speed)
        self.verticalLayout_14.addLayout(self.horizontalLayout_13)
        self.lbl_speed = QtWidgets.QLabel(self.widget_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lbl_speed.sizePolicy().hasHeightForWidth())
        self.lbl_speed.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_speed.setFont(font)
        self.lbl_speed.setStyleSheet("border:none")
        self.lbl_speed.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_speed.setObjectName("lbl_speed")
        self.verticalLayout_14.addWidget(self.lbl_speed)
        self.horizontalLayout_12.addWidget(self.widget_8)
        self.gridLayout_3.addLayout(self.horizontalLayout_12, 2, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(500, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem1, 0, 1, 1, 1)
        self.widget_12 = QtWidgets.QWidget(self.page_main)
        self.widget_12.setMinimumSize(QtCore.QSize(177, 100))
        self.widget_12.setStyleSheet("background-color: rgb(248, 248, 248);\n"
"border: 2px solid black;\n"
"border-radius: 5px;")
        self.widget_12.setObjectName("widget_12")
        self.verticalLayout_18 = QtWidgets.QVBoxLayout(self.widget_12)
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.img_heart = QtWidgets.QLabel(self.widget_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(35)
        sizePolicy.setHeightForWidth(self.img_heart.sizePolicy().hasHeightForWidth())
        self.img_heart.setSizePolicy(sizePolicy)
        self.img_heart.setMinimumSize(QtCore.QSize(40, 35))
        self.img_heart.setMaximumSize(QtCore.QSize(40, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setItalic(False)
        self.img_heart.setFont(font)
        self.img_heart.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.img_heart.setStyleSheet("border: none;")
        self.img_heart.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.img_heart.setFrameShadow(QtWidgets.QFrame.Plain)
        self.img_heart.setText("")
        self.img_heart.setPixmap(QtGui.QPixmap("../ast_monitor/icons/heart.svg"))
        self.img_heart.setScaledContents(True)
        self.img_heart.setAlignment(QtCore.Qt.AlignCenter)
        self.img_heart.setObjectName("img_heart")
        self.horizontalLayout_17.addWidget(self.img_heart)
        self.verticalLayout_18.addLayout(self.horizontalLayout_17)
        self.lbl_heart_rate = QtWidgets.QLabel(self.widget_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(48)
        sizePolicy.setVerticalStretch(33)
        sizePolicy.setHeightForWidth(self.lbl_heart_rate.sizePolicy().hasHeightForWidth())
        self.lbl_heart_rate.setSizePolicy(sizePolicy)
        self.lbl_heart_rate.setMinimumSize(QtCore.QSize(48, 33))
        self.lbl_heart_rate.setMaximumSize(QtCore.QSize(500, 33))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_heart_rate.setFont(font)
        self.lbl_heart_rate.setStyleSheet("border:none")
        self.lbl_heart_rate.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_heart_rate.setObjectName("lbl_heart_rate")
        self.verticalLayout_18.addWidget(self.lbl_heart_rate, 0, QtCore.Qt.AlignHCenter)
        self.gridLayout_3.addWidget(self.widget_12, 4, 0, 1, 1)
        self.widget_9 = QtWidgets.QWidget(self.page_main)
        self.widget_9.setMinimumSize(QtCore.QSize(177, 100))
        self.widget_9.setStyleSheet("background-color: rgb(248, 248, 248);\n"
"border: 2px solid black;\n"
"border-radius: 5px;")
        self.widget_9.setObjectName("widget_9")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.widget_9)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.img_ascent = QtWidgets.QLabel(self.widget_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(40)
        sizePolicy.setHeightForWidth(self.img_ascent.sizePolicy().hasHeightForWidth())
        self.img_ascent.setSizePolicy(sizePolicy)
        self.img_ascent.setMinimumSize(QtCore.QSize(65, 35))
        self.img_ascent.setMaximumSize(QtCore.QSize(65, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setItalic(False)
        self.img_ascent.setFont(font)
        self.img_ascent.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.img_ascent.setStyleSheet("border: none")
        self.img_ascent.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.img_ascent.setFrameShadow(QtWidgets.QFrame.Plain)
        self.img_ascent.setText("")
        self.img_ascent.setPixmap(QtGui.QPixmap("../ast_monitor/icons/ascent.svg"))
        self.img_ascent.setScaledContents(True)
        self.img_ascent.setAlignment(QtCore.Qt.AlignCenter)
        self.img_ascent.setObjectName("img_ascent")
        self.horizontalLayout_14.addWidget(self.img_ascent)
        self.verticalLayout_6.addLayout(self.horizontalLayout_14)
        self.lbl_ascent = QtWidgets.QLabel(self.widget_9)
        self.lbl_ascent.setMaximumSize(QtCore.QSize(16777215, 50))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_ascent.setFont(font)
        self.lbl_ascent.setStyleSheet("border: none;")
        self.lbl_ascent.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_ascent.setObjectName("lbl_ascent")
        self.verticalLayout_6.addWidget(self.lbl_ascent)
        self.gridLayout_3.addWidget(self.widget_9, 4, 2, 1, 1)
        self.widget_10 = QtWidgets.QWidget(self.page_main)
        self.widget_10.setMinimumSize(QtCore.QSize(177, 100))
        self.widget_10.setStyleSheet("background-color: rgb(248, 248, 248);\n"
"border: 2px solid black;\n"
"border-radius: 5px;")
        self.widget_10.setObjectName("widget_10")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout(self.widget_10)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.img_clock = QtWidgets.QLabel(self.widget_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(40)
        sizePolicy.setHeightForWidth(self.img_clock.sizePolicy().hasHeightForWidth())
        self.img_clock.setSizePolicy(sizePolicy)
        self.img_clock.setMinimumSize(QtCore.QSize(30, 35))
        self.img_clock.setMaximumSize(QtCore.QSize(30, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setItalic(False)
        self.img_clock.setFont(font)
        self.img_clock.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.img_clock.setStyleSheet("border: none")
        self.img_clock.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.img_clock.setFrameShadow(QtWidgets.QFrame.Plain)
        self.img_clock.setText("")
        self.img_clock.setPixmap(QtGui.QPixmap("../ast_monitor/icons/clock.svg"))
        self.img_clock.setScaledContents(True)
        self.img_clock.setAlignment(QtCore.Qt.AlignCenter)
        self.img_clock.setObjectName("img_clock")
        self.horizontalLayout_15.addWidget(self.img_clock)
        self.verticalLayout_16.addLayout(self.horizontalLayout_15)
        self.widget_2 = QtWidgets.QWidget(self.widget_10)
        self.widget_2.setStyleSheet("border:none")
        self.widget_2.setObjectName("widget_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.widget_2)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lbl_watch = QtWidgets.QLabel(self.widget_2)
        self.lbl_watch.setMinimumSize(QtCore.QSize(120, 30))
        self.lbl_watch.setMaximumSize(QtCore.QSize(150, 16777215))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_watch.setFont(font)
        self.lbl_watch.setStyleSheet("")
        self.lbl_watch.setTextFormat(QtCore.Qt.AutoText)
        self.lbl_watch.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_watch.setObjectName("lbl_watch")
        self.horizontalLayout_2.addWidget(self.lbl_watch)
        self.verticalLayout_16.addWidget(self.widget_2)
        self.gridLayout_3.addWidget(self.widget_10, 0, 2, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_3.addItem(spacerItem2, 1, 0, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_3.addItem(spacerItem3, 3, 0, 1, 1)
        self.verticalLayout_12.addLayout(self.gridLayout_3)
        self.stackedWidget.addWidget(self.page_main)
        self.page_map = QtWidgets.QWidget()
        self.page_map.setStyleSheet("")
        self.page_map.setObjectName("page_map")
        self.verticalLayout_19 = QtWidgets.QVBoxLayout(self.page_map)
        self.verticalLayout_19.setContentsMargins(9, 1, 9, 1)
        self.verticalLayout_19.setObjectName("verticalLayout_19")
        self.widget_13 = QtWidgets.QWidget(self.page_map)
        self.widget_13.setStyleSheet("border: 1px solid black;")
        self.widget_13.setObjectName("widget_13")
        self.verticalLayout_20 = QtWidgets.QVBoxLayout(self.widget_13)
        self.verticalLayout_20.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_20.setObjectName("verticalLayout_20")
        self.vb_map = QtWidgets.QVBoxLayout()
        self.vb_map.setContentsMargins(1, 1, 1, 1)
        self.vb_map.setSpacing(0)
        self.vb_map.setObjectName("vb_map")
        self.verticalLayout_20.addLayout(self.vb_map)
        self.verticalLayout_19.addWidget(self.widget_13)
        self.stackedWidget.addWidget(self.page_map)
        self.page_interval = QtWidgets.QWidget()
        self.page_interval.setObjectName("page_interval")
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout(self.page_interval)
        self.horizontalLayout_22.setContentsMargins(60, 15, 60, 15)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.widget_18 = QtWidgets.QWidget(self.page_interval)
        self.widget_18.setMinimumSize(QtCore.QSize(177, 100))
        self.widget_18.setMaximumSize(QtCore.QSize(177, 100))
        self.widget_18.setStyleSheet("background-color: rgb(248, 248, 248);\n"
"border: 2px solid black;\n"
"border-radius: 5px;")
        self.widget_18.setObjectName("widget_18")
        self.verticalLayout_27 = QtWidgets.QVBoxLayout(self.widget_18)
        self.verticalLayout_27.setObjectName("verticalLayout_27")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_20.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.widget_4 = QtWidgets.QWidget(self.widget_18)
        self.widget_4.setMaximumSize(QtCore.QSize(40, 35))
        self.widget_4.setStyleSheet("border:none;")
        self.widget_4.setObjectName("widget_4")
        self.img_heart_3 = QtWidgets.QLabel(self.widget_4)
        self.img_heart_3.setGeometry(QtCore.QRect(0, 0, 40, 35))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(35)
        sizePolicy.setHeightForWidth(self.img_heart_3.sizePolicy().hasHeightForWidth())
        self.img_heart_3.setSizePolicy(sizePolicy)
        self.img_heart_3.setMinimumSize(QtCore.QSize(40, 35))
        self.img_heart_3.setMaximumSize(QtCore.QSize(40, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setItalic(False)
        self.img_heart_3.setFont(font)
        self.img_heart_3.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.img_heart_3.setStyleSheet("border: none;")
        self.img_heart_3.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.img_heart_3.setFrameShadow(QtWidgets.QFrame.Plain)
        self.img_heart_3.setText("")
        self.img_heart_3.setTextFormat(QtCore.Qt.PlainText)
        self.img_heart_3.setPixmap(QtGui.QPixmap("../ast_monitor/icons/heart.svg"))
        self.img_heart_3.setScaledContents(True)
        self.img_heart_3.setAlignment(QtCore.Qt.AlignCenter)
        self.img_heart_3.setObjectName("img_heart_3")
        self.label_2 = QtWidgets.QLabel(self.widget_4)
        self.label_2.setGeometry(QtCore.QRect(0, 0, 41, 31))
        self.label_2.setStyleSheet("font: 14px \"Bahnschrift\"; border: none; background-color: rgba(0,0,0,0); color: white;")
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_20.addWidget(self.widget_4)
        self.verticalLayout_27.addLayout(self.horizontalLayout_20)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setContentsMargins(-1, -1, -1, 5)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.lbl_interval_average_heart_rate = QtWidgets.QLabel(self.widget_18)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(48)
        sizePolicy.setVerticalStretch(33)
        sizePolicy.setHeightForWidth(self.lbl_interval_average_heart_rate.sizePolicy().hasHeightForWidth())
        self.lbl_interval_average_heart_rate.setSizePolicy(sizePolicy)
        self.lbl_interval_average_heart_rate.setMinimumSize(QtCore.QSize(120, 10))
        self.lbl_interval_average_heart_rate.setMaximumSize(QtCore.QSize(120, 30))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_interval_average_heart_rate.setFont(font)
        self.lbl_interval_average_heart_rate.setStyleSheet("border:none")
        self.lbl_interval_average_heart_rate.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_interval_average_heart_rate.setObjectName("lbl_interval_average_heart_rate")
        self.horizontalLayout_8.addWidget(self.lbl_interval_average_heart_rate)
        self.verticalLayout_27.addLayout(self.horizontalLayout_8)
        self.gridLayout.addWidget(self.widget_18, 2, 0, 1, 1)
        self.widget_19 = QtWidgets.QWidget(self.page_interval)
        self.widget_19.setMinimumSize(QtCore.QSize(177, 100))
        self.widget_19.setMaximumSize(QtCore.QSize(177, 100))
        self.widget_19.setStyleSheet("background-color: rgb(248, 248, 248);\n"
"border: 2px solid black;\n"
"border-radius: 5px;")
        self.widget_19.setObjectName("widget_19")
        self.verticalLayout_28 = QtWidgets.QVBoxLayout(self.widget_19)
        self.verticalLayout_28.setObjectName("verticalLayout_28")
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_21.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.widget_6 = QtWidgets.QWidget(self.widget_19)
        self.widget_6.setMaximumSize(QtCore.QSize(40, 35))
        self.widget_6.setStyleSheet("border:none;")
        self.widget_6.setObjectName("widget_6")
        self.img_heart_4 = QtWidgets.QLabel(self.widget_6)
        self.img_heart_4.setGeometry(QtCore.QRect(0, 0, 40, 35))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(35)
        sizePolicy.setHeightForWidth(self.img_heart_4.sizePolicy().hasHeightForWidth())
        self.img_heart_4.setSizePolicy(sizePolicy)
        self.img_heart_4.setMinimumSize(QtCore.QSize(40, 35))
        self.img_heart_4.setMaximumSize(QtCore.QSize(40, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setItalic(False)
        self.img_heart_4.setFont(font)
        self.img_heart_4.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.img_heart_4.setStyleSheet("border: none;")
        self.img_heart_4.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.img_heart_4.setFrameShadow(QtWidgets.QFrame.Plain)
        self.img_heart_4.setText("")
        self.img_heart_4.setTextFormat(QtCore.Qt.PlainText)
        self.img_heart_4.setPixmap(QtGui.QPixmap("../ast_monitor/icons/heart.svg"))
        self.img_heart_4.setScaledContents(True)
        self.img_heart_4.setAlignment(QtCore.Qt.AlignCenter)
        self.img_heart_4.setObjectName("img_heart_4")
        self.label_3 = QtWidgets.QLabel(self.widget_6)
        self.label_3.setGeometry(QtCore.QRect(0, 0, 41, 31))
        self.label_3.setStyleSheet("font: 14px \"Bahnschrift\"; border: none; background-color: rgba(0,0,0,0); color: white;")
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_21.addWidget(self.widget_6)
        self.verticalLayout_28.addLayout(self.horizontalLayout_21)
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_23.setContentsMargins(-1, -1, -1, 5)
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.lbl_interval_proposed_heart_rate = QtWidgets.QLabel(self.widget_19)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(48)
        sizePolicy.setVerticalStretch(33)
        sizePolicy.setHeightForWidth(self.lbl_interval_proposed_heart_rate.sizePolicy().hasHeightForWidth())
        self.lbl_interval_proposed_heart_rate.setSizePolicy(sizePolicy)
        self.lbl_interval_proposed_heart_rate.setMinimumSize(QtCore.QSize(120, 10))
        self.lbl_interval_proposed_heart_rate.setMaximumSize(QtCore.QSize(120, 30))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_interval_proposed_heart_rate.setFont(font)
        self.lbl_interval_proposed_heart_rate.setStyleSheet("border:none")
        self.lbl_interval_proposed_heart_rate.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_interval_proposed_heart_rate.setObjectName("lbl_interval_proposed_heart_rate")
        self.horizontalLayout_23.addWidget(self.lbl_interval_proposed_heart_rate)
        self.verticalLayout_28.addLayout(self.horizontalLayout_23)
        self.gridLayout.addWidget(self.widget_19, 2, 2, 1, 1)
        self.horizontalLayout_27 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_27.setObjectName("horizontalLayout_27")
        self.widget_20 = QtWidgets.QWidget(self.page_interval)
        self.widget_20.setMinimumSize(QtCore.QSize(177, 100))
        self.widget_20.setMaximumSize(QtCore.QSize(177, 100))
        self.widget_20.setStyleSheet("background-color: rgb(248, 248, 248);\n"
"border: 2px solid black;\n"
"border-radius: 5px;")
        self.widget_20.setObjectName("widget_20")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.widget_20)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout()
        self.verticalLayout_13.setContentsMargins(-1, -1, -1, 5)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.swgt_interval_performance = QtWidgets.QStackedWidget(self.widget_20)
        self.swgt_interval_performance.setStyleSheet("border: none;")
        self.swgt_interval_performance.setObjectName("swgt_interval_performance")
        self.page_11 = QtWidgets.QWidget()
        self.page_11.setObjectName("page_11")
        self.horizontalLayout_26 = QtWidgets.QHBoxLayout(self.page_11)
        self.horizontalLayout_26.setObjectName("horizontalLayout_26")
        self.lbl_interval_performance = QtWidgets.QLabel(self.page_11)
        self.lbl_interval_performance.setMinimumSize(QtCore.QSize(0, 63))
        self.lbl_interval_performance.setMaximumSize(QtCore.QSize(200, 120))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift SemiLight")
        font.setPointSize(17)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_interval_performance.setFont(font)
        self.lbl_interval_performance.setStyleSheet("border:none;")
        self.lbl_interval_performance.setTextFormat(QtCore.Qt.AutoText)
        self.lbl_interval_performance.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_interval_performance.setObjectName("lbl_interval_performance")
        self.horizontalLayout_26.addWidget(self.lbl_interval_performance)
        self.swgt_interval_performance.addWidget(self.page_11)
        self.page_6 = QtWidgets.QWidget()
        self.page_6.setObjectName("page_6")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.page_6)
        self.verticalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_9.setSpacing(0)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.horizontalLayout_25 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_25.setSpacing(0)
        self.horizontalLayout_25.setObjectName("horizontalLayout_25")
        self.lbl_interval_arrow_up = QtWidgets.QLabel(self.page_6)
        self.lbl_interval_arrow_up.setMinimumSize(QtCore.QSize(0, 0))
        self.lbl_interval_arrow_up.setMaximumSize(QtCore.QSize(80, 80))
        self.lbl_interval_arrow_up.setSizeIncrement(QtCore.QSize(0, 0))
        self.lbl_interval_arrow_up.setText("")
        self.lbl_interval_arrow_up.setPixmap(QtGui.QPixmap("../ast_monitor/icons/arrow_up.svg"))
        self.lbl_interval_arrow_up.setScaledContents(False)
        self.lbl_interval_arrow_up.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_interval_arrow_up.setObjectName("lbl_interval_arrow_up")
        self.horizontalLayout_25.addWidget(self.lbl_interval_arrow_up)
        self.verticalLayout_7.addLayout(self.horizontalLayout_25)
        self.horizontalLayout_28 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_28.setObjectName("horizontalLayout_28")
        self.lbl_interval_performance_up = QtWidgets.QLabel(self.page_6)
        self.lbl_interval_performance_up.setMinimumSize(QtCore.QSize(0, 20))
        self.lbl_interval_performance_up.setMaximumSize(QtCore.QSize(150, 120))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_interval_performance_up.setFont(font)
        self.lbl_interval_performance_up.setStyleSheet("border:none;")
        self.lbl_interval_performance_up.setTextFormat(QtCore.Qt.AutoText)
        self.lbl_interval_performance_up.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_interval_performance_up.setObjectName("lbl_interval_performance_up")
        self.horizontalLayout_28.addWidget(self.lbl_interval_performance_up)
        self.verticalLayout_7.addLayout(self.horizontalLayout_28)
        self.verticalLayout_9.addLayout(self.verticalLayout_7)
        self.swgt_interval_performance.addWidget(self.page_6)
        self.page_7 = QtWidgets.QWidget()
        self.page_7.setObjectName("page_7")
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout(self.page_7)
        self.horizontalLayout_24.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.verticalLayout_29 = QtWidgets.QVBoxLayout()
        self.verticalLayout_29.setObjectName("verticalLayout_29")
        self.horizontalLayout_29 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_29.setSpacing(0)
        self.horizontalLayout_29.setObjectName("horizontalLayout_29")
        self.label_5 = QtWidgets.QLabel(self.page_7)
        self.label_5.setMinimumSize(QtCore.QSize(0, 0))
        self.label_5.setMaximumSize(QtCore.QSize(80, 80))
        self.label_5.setSizeIncrement(QtCore.QSize(0, 0))
        self.label_5.setText("")
        self.label_5.setPixmap(QtGui.QPixmap("../ast_monitor/icons/arrow_down.svg"))
        self.label_5.setScaledContents(False)
        self.label_5.setAlignment(QtCore.Qt.AlignCenter)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_29.addWidget(self.label_5)
        self.verticalLayout_29.addLayout(self.horizontalLayout_29)
        self.horizontalLayout_30 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_30.setObjectName("horizontalLayout_30")
        self.lbl_interval_performance_down = QtWidgets.QLabel(self.page_7)
        self.lbl_interval_performance_down.setMinimumSize(QtCore.QSize(0, 20))
        self.lbl_interval_performance_down.setMaximumSize(QtCore.QSize(150, 120))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_interval_performance_down.setFont(font)
        self.lbl_interval_performance_down.setStyleSheet("border:none;")
        self.lbl_interval_performance_down.setTextFormat(QtCore.Qt.AutoText)
        self.lbl_interval_performance_down.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_interval_performance_down.setObjectName("lbl_interval_performance_down")
        self.horizontalLayout_30.addWidget(self.lbl_interval_performance_down)
        self.verticalLayout_29.addLayout(self.horizontalLayout_30)
        self.horizontalLayout_24.addLayout(self.verticalLayout_29)
        self.swgt_interval_performance.addWidget(self.page_7)
        self.verticalLayout_13.addWidget(self.swgt_interval_performance)
        self.verticalLayout_5.addLayout(self.verticalLayout_13)
        self.horizontalLayout_27.addWidget(self.widget_20)
        self.gridLayout.addLayout(self.horizontalLayout_27, 1, 1, 1, 1)
        self.widget_17 = QtWidgets.QWidget(self.page_interval)
        self.widget_17.setMinimumSize(QtCore.QSize(170, 100))
        self.widget_17.setMaximumSize(QtCore.QSize(170, 100))
        self.widget_17.setStyleSheet("background-color: rgb(248, 248, 248);\n"
"border: 2px solid black;\n"
"border-radius: 5px;")
        self.widget_17.setObjectName("widget_17")
        self.verticalLayout_26 = QtWidgets.QVBoxLayout(self.widget_17)
        self.verticalLayout_26.setObjectName("verticalLayout_26")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_19.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.widget_3 = QtWidgets.QWidget(self.widget_17)
        self.widget_3.setMaximumSize(QtCore.QSize(40, 35))
        self.widget_3.setStyleSheet("border:none;")
        self.widget_3.setObjectName("widget_3")
        self.img_heart_2 = QtWidgets.QLabel(self.widget_3)
        self.img_heart_2.setGeometry(QtCore.QRect(0, 0, 40, 35))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(35)
        sizePolicy.setHeightForWidth(self.img_heart_2.sizePolicy().hasHeightForWidth())
        self.img_heart_2.setSizePolicy(sizePolicy)
        self.img_heart_2.setMinimumSize(QtCore.QSize(40, 35))
        self.img_heart_2.setMaximumSize(QtCore.QSize(40, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setItalic(False)
        self.img_heart_2.setFont(font)
        self.img_heart_2.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.img_heart_2.setStyleSheet("border: none;")
        self.img_heart_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.img_heart_2.setFrameShadow(QtWidgets.QFrame.Plain)
        self.img_heart_2.setText("")
        self.img_heart_2.setTextFormat(QtCore.Qt.PlainText)
        self.img_heart_2.setPixmap(QtGui.QPixmap("../ast_monitor/icons/heart.svg"))
        self.img_heart_2.setScaledContents(True)
        self.img_heart_2.setAlignment(QtCore.Qt.AlignCenter)
        self.img_heart_2.setObjectName("img_heart_2")
        self.label = QtWidgets.QLabel(self.widget_3)
        self.label.setGeometry(QtCore.QRect(0, 0, 41, 31))
        self.label.setStyleSheet("font: 14px \"Bahnschrift\"; border: none; background-color: rgba(0,0,0,0); color: white;")
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.horizontalLayout_19.addWidget(self.widget_3)
        self.verticalLayout_26.addLayout(self.horizontalLayout_19)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setContentsMargins(-1, -1, -1, 5)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.lbl_interval_heart_rate = QtWidgets.QLabel(self.widget_17)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(48)
        sizePolicy.setVerticalStretch(33)
        sizePolicy.setHeightForWidth(self.lbl_interval_heart_rate.sizePolicy().hasHeightForWidth())
        self.lbl_interval_heart_rate.setSizePolicy(sizePolicy)
        self.lbl_interval_heart_rate.setMinimumSize(QtCore.QSize(120, 10))
        self.lbl_interval_heart_rate.setMaximumSize(QtCore.QSize(120, 30))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_interval_heart_rate.setFont(font)
        self.lbl_interval_heart_rate.setStyleSheet("border:none")
        self.lbl_interval_heart_rate.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_interval_heart_rate.setObjectName("lbl_interval_heart_rate")
        self.horizontalLayout_6.addWidget(self.lbl_interval_heart_rate)
        self.verticalLayout_26.addLayout(self.horizontalLayout_6)
        self.gridLayout.addWidget(self.widget_17, 0, 2, 1, 1)
        self.widget_16 = QtWidgets.QWidget(self.page_interval)
        self.widget_16.setMinimumSize(QtCore.QSize(177, 100))
        self.widget_16.setMaximumSize(QtCore.QSize(177, 100))
        self.widget_16.setStyleSheet("background-color: rgb(248, 248, 248);\n"
"border: 2px solid black;\n"
"border-radius: 5px;")
        self.widget_16.setObjectName("widget_16")
        self.verticalLayout_25 = QtWidgets.QVBoxLayout(self.widget_16)
        self.verticalLayout_25.setObjectName("verticalLayout_25")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_18.setContentsMargins(-1, 5, -1, -1)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.img_clock_2 = QtWidgets.QLabel(self.widget_16)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(40)
        sizePolicy.setVerticalStretch(40)
        sizePolicy.setHeightForWidth(self.img_clock_2.sizePolicy().hasHeightForWidth())
        self.img_clock_2.setSizePolicy(sizePolicy)
        self.img_clock_2.setMinimumSize(QtCore.QSize(30, 35))
        self.img_clock_2.setMaximumSize(QtCore.QSize(30, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setItalic(False)
        self.img_clock_2.setFont(font)
        self.img_clock_2.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.img_clock_2.setStyleSheet("border: none;")
        self.img_clock_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.img_clock_2.setFrameShadow(QtWidgets.QFrame.Plain)
        self.img_clock_2.setText("")
        self.img_clock_2.setPixmap(QtGui.QPixmap("../ast_monitor/icons/clock.svg"))
        self.img_clock_2.setScaledContents(True)
        self.img_clock_2.setAlignment(QtCore.Qt.AlignCenter)
        self.img_clock_2.setObjectName("img_clock_2")
        self.horizontalLayout_18.addWidget(self.img_clock_2)
        self.verticalLayout_25.addLayout(self.horizontalLayout_18)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setContentsMargins(-1, -1, -1, 5)
        self.horizontalLayout_5.setSpacing(0)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.lbl_interval_watch = QtWidgets.QLabel(self.widget_16)
        self.lbl_interval_watch.setMinimumSize(QtCore.QSize(120, 10))
        self.lbl_interval_watch.setMaximumSize(QtCore.QSize(150, 30))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift Light")
        font.setPointSize(25)
        font.setBold(False)
        font.setItalic(False)
        self.lbl_interval_watch.setFont(font)
        self.lbl_interval_watch.setStyleSheet("border:none;")
        self.lbl_interval_watch.setTextFormat(QtCore.Qt.AutoText)
        self.lbl_interval_watch.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_interval_watch.setObjectName("lbl_interval_watch")
        self.horizontalLayout_5.addWidget(self.lbl_interval_watch)
        self.verticalLayout_25.addLayout(self.horizontalLayout_5)
        self.gridLayout.addWidget(self.widget_16, 0, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.gridLayout.addLayout(self.horizontalLayout_3, 1, 2, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(500, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem4, 0, 1, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem5, 1, 0, 1, 1)
        self.horizontalLayout_22.addLayout(self.gridLayout)
        self.stackedWidget.addWidget(self.page_interval)
        self.page_training = QtWidgets.QWidget()
        self.page_training.setObjectName("page_training")
        self.verticalLayout_30 = QtWidgets.QVBoxLayout(self.page_training)
        self.verticalLayout_30.setContentsMargins(-1, 0, -1, 0)
        self.verticalLayout_30.setObjectName("verticalLayout_30")
        self.widget_training_data = QtWidgets.QStackedWidget(self.page_training)
        self.widget_training_data.setObjectName("widget_training_data")
        self.page_12 = QtWidgets.QWidget()
        self.page_12.setObjectName("page_12")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.page_12)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.lbl_no_training = QtWidgets.QLabel(self.page_12)
        self.lbl_no_training.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_no_training.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_no_training.setObjectName("lbl_no_training")
        self.verticalLayout_11.addWidget(self.lbl_no_training)
        self.widget_training_data.addWidget(self.page_12)
        self.page_13 = QtWidgets.QWidget()
        self.page_13.setObjectName("page_13")
        self.verticalLayout_32 = QtWidgets.QVBoxLayout(self.page_13)
        self.verticalLayout_32.setObjectName("verticalLayout_32")
        self.verticalLayout_31 = QtWidgets.QVBoxLayout()
        self.verticalLayout_31.setContentsMargins(160, -1, 160, -1)
        self.verticalLayout_31.setSpacing(20)
        self.verticalLayout_31.setObjectName("verticalLayout_31")
        self.lbl_training_file = QtWidgets.QLabel(self.page_13)
        self.lbl_training_file.setStyleSheet("font: 25px \"Bahnschrift Semibold\";")
        self.lbl_training_file.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl_training_file.setObjectName("lbl_training_file")
        self.verticalLayout_31.addWidget(self.lbl_training_file)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setContentsMargins(5, 5, 5, 5)
        self.gridLayout_2.setHorizontalSpacing(80)
        self.gridLayout_2.setVerticalSpacing(13)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.lbl_training_type = QtWidgets.QLabel(self.page_13)
        self.lbl_training_type.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_type.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_type.setObjectName("lbl_training_type")
        self.gridLayout_2.addWidget(self.lbl_training_type, 0, 1, 1, 1)
        self.lbl_training_speed_hr = QtWidgets.QLabel(self.page_13)
        self.lbl_training_speed_hr.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_speed_hr.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_speed_hr.setObjectName("lbl_training_speed_hr")
        self.gridLayout_2.addWidget(self.lbl_training_speed_hr, 2, 1, 1, 1)
        self.lbl_training_speed_hr_title = QtWidgets.QLabel(self.page_13)
        self.lbl_training_speed_hr_title.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_speed_hr_title.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_speed_hr_title.setObjectName("lbl_training_speed_hr_title")
        self.gridLayout_2.addWidget(self.lbl_training_speed_hr_title, 2, 0, 1, 1)
        self.lbl_training_rest_duration_title = QtWidgets.QLabel(self.page_13)
        self.lbl_training_rest_duration_title.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_rest_duration_title.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_rest_duration_title.setObjectName("lbl_training_rest_duration_title")
        self.gridLayout_2.addWidget(self.lbl_training_rest_duration_title, 3, 0, 1, 1)
        self.lbl_training_rest_duration = QtWidgets.QLabel(self.page_13)
        self.lbl_training_rest_duration.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_rest_duration.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_rest_duration.setObjectName("lbl_training_rest_duration")
        self.gridLayout_2.addWidget(self.lbl_training_rest_duration, 3, 1, 1, 1)
        self.lbl_training_type_title = QtWidgets.QLabel(self.page_13)
        self.lbl_training_type_title.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_type_title.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_type_title.setObjectName("lbl_training_type_title")
        self.gridLayout_2.addWidget(self.lbl_training_type_title, 0, 0, 1, 1)
        self.lbl_training_speed_duration_title = QtWidgets.QLabel(self.page_13)
        self.lbl_training_speed_duration_title.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_speed_duration_title.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_speed_duration_title.setObjectName("lbl_training_speed_duration_title")
        self.gridLayout_2.addWidget(self.lbl_training_speed_duration_title, 1, 0, 1, 1)
        self.lbl_training_speed_duration = QtWidgets.QLabel(self.page_13)
        self.lbl_training_speed_duration.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_speed_duration.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_speed_duration.setObjectName("lbl_training_speed_duration")
        self.gridLayout_2.addWidget(self.lbl_training_speed_duration, 1, 1, 1, 1)
        self.lbl_training_rest_hr_title = QtWidgets.QLabel(self.page_13)
        self.lbl_training_rest_hr_title.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_rest_hr_title.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_rest_hr_title.setObjectName("lbl_training_rest_hr_title")
        self.gridLayout_2.addWidget(self.lbl_training_rest_hr_title, 4, 0, 1, 1)
        self.lbl_training_repetitions_title = QtWidgets.QLabel(self.page_13)
        self.lbl_training_repetitions_title.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_repetitions_title.setObjectName("lbl_training_repetitions_title")
        self.gridLayout_2.addWidget(self.lbl_training_repetitions_title, 5, 0, 1, 1)
        self.lbl_training_rest_hr = QtWidgets.QLabel(self.page_13)
        self.lbl_training_rest_hr.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_rest_hr.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_rest_hr.setObjectName("lbl_training_rest_hr")
        self.gridLayout_2.addWidget(self.lbl_training_rest_hr, 4, 1, 1, 1)
        self.lbl_training_repetitions = QtWidgets.QLabel(self.page_13)
        self.lbl_training_repetitions.setStyleSheet("font: 22px \"Bahnschrift Semilight\";")
        self.lbl_training_repetitions.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.lbl_training_repetitions.setObjectName("lbl_training_repetitions")
        self.gridLayout_2.addWidget(self.lbl_training_repetitions, 5, 1, 1, 1)
        self.verticalLayout_31.addLayout(self.gridLayout_2)
        self.verticalLayout_32.addLayout(self.verticalLayout_31)
        self.widget_training_data.addWidget(self.page_13)
        self.verticalLayout_30.addWidget(self.widget_training_data)
        self.lyt_training = QtWidgets.QVBoxLayout()
        self.lyt_training.setSpacing(0)
        self.lyt_training.setObjectName("lyt_training")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem6)
        self.btn_load_training = QtWidgets.QPushButton(self.page_training)
        self.btn_load_training.setMinimumSize(QtCore.QSize(70, 40))
        self.btn_load_training.setMaximumSize(QtCore.QSize(70, 40))
        self.btn_load_training.setStyleSheet("font: 20px \"Bahnschrift Semilight\";\n"
"background-color: rgb(255, 255, 255);\n"
"border: 1px solid black;\n"
"border-radius: 5px;")
        self.btn_load_training.setIconSize(QtCore.QSize(16, 16))
        self.btn_load_training.setObjectName("btn_load_training")
        self.horizontalLayout_4.addWidget(self.btn_load_training)
        self.stackedWidget_2 = QtWidgets.QStackedWidget(self.page_training)
        self.stackedWidget_2.setMaximumSize(QtCore.QSize(80, 16777215))
        self.stackedWidget_2.setObjectName("stackedWidget_2")
        self.page_9 = QtWidgets.QWidget()
        self.page_9.setObjectName("page_9")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.page_9)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.btn_start_training = QtWidgets.QPushButton(self.page_9)
        self.btn_start_training.setMinimumSize(QtCore.QSize(70, 40))
        self.btn_start_training.setMaximumSize(QtCore.QSize(70, 40))
        self.btn_start_training.setStyleSheet("font: 20px \"Bahnschrift Semilight\";\n"
"background-color: rgb(255, 255, 255);\n"
"border: 1px solid black;\n"
"border-radius: 5px;")
        self.btn_start_training.setObjectName("btn_start_training")
        self.verticalLayout_8.addWidget(self.btn_start_training)
        self.stackedWidget_2.addWidget(self.page_9)
        self.page_10 = QtWidgets.QWidget()
        self.page_10.setObjectName("page_10")
        self.stackedWidget_2.addWidget(self.page_10)
        self.horizontalLayout_4.addWidget(self.stackedWidget_2)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem7)
        self.lyt_training.addLayout(self.horizontalLayout_4)
        self.verticalLayout_30.addLayout(self.lyt_training)
        self.verticalLayout_30.setStretch(0, 1)
        self.stackedWidget.addWidget(self.page_training)
        self.horizontalLayout_11.addWidget(self.stackedWidget)
        self.btn_move_right = QtWidgets.QPushButton(self.widget_14)
        self.btn_move_right.setStyleSheet("background-color: rgba(255, 255, 255, 0);")
        self.btn_move_right.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("../ast_monitor/icons/arrow_right.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_move_right.setIcon(icon1)
        self.btn_move_right.setIconSize(QtCore.QSize(30, 50))
        self.btn_move_right.setFlat(False)
        self.btn_move_right.setObjectName("btn_move_right")
        self.horizontalLayout_11.addWidget(self.btn_move_right)
        self.verticalLayout_21.addLayout(self.horizontalLayout_11)
        self.verticalLayout_23.addWidget(self.widget_14)
        self.widget_15 = QtWidgets.QWidget(self.centralwidget)
        self.widget_15.setStyleSheet("background-color: rgba(240, 240, 240, 1);border-top: 1px solid black;")
        self.widget_15.setObjectName("widget_15")
        self.verticalLayout_22 = QtWidgets.QVBoxLayout(self.widget_15)
        self.verticalLayout_22.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_22.setSpacing(0)
        self.verticalLayout_22.setObjectName("verticalLayout_22")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setContentsMargins(15, 1, 15, 1)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.btn_shutdown = QtWidgets.QPushButton(self.widget_15)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btn_shutdown.sizePolicy().hasHeightForWidth())
        self.btn_shutdown.setSizePolicy(sizePolicy)
        self.btn_shutdown.setMaximumSize(QtCore.QSize(50, 50))
        self.btn_shutdown.setAutoFillBackground(False)
        self.btn_shutdown.setStyleSheet("background-color: rgba(255, 255, 255, 0);\n"
"border: none;")
        self.btn_shutdown.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("../ast_monitor/icons/shutdown.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_shutdown.setIcon(icon2)
        self.btn_shutdown.setIconSize(QtCore.QSize(50, 50))
        self.btn_shutdown.setAutoRepeat(False)
        self.btn_shutdown.setFlat(False)
        self.btn_shutdown.setObjectName("btn_shutdown")
        self.horizontalLayout_7.addWidget(self.btn_shutdown)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem8)
        self.widget_start_stop = QtWidgets.QStackedWidget(self.widget_15)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.widget_start_stop.sizePolicy().hasHeightForWidth())
        self.widget_start_stop.setSizePolicy(sizePolicy)
        self.widget_start_stop.setMinimumSize(QtCore.QSize(120, 0))
        self.widget_start_stop.setMaximumSize(QtCore.QSize(120, 70))
        self.widget_start_stop.setStyleSheet("border-top: 0px solid black;")
        self.widget_start_stop.setObjectName("widget_start_stop")
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout(self.page)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.btn_start_tracking = QtWidgets.QPushButton(self.page)
        self.btn_start_tracking.setMinimumSize(QtCore.QSize(50, 50))
        self.btn_start_tracking.setMaximumSize(QtCore.QSize(50, 50))
        self.btn_start_tracking.setStyleSheet("background-color: rgb(255, 255, 255);\n"
"border: 1px solid black;\n"
"border-radius: 5px;")
        self.btn_start_tracking.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("../ast_monitor/icons/play.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_start_tracking.setIcon(icon3)
        self.btn_start_tracking.setIconSize(QtCore.QSize(30, 30))
        self.btn_start_tracking.setFlat(False)
        self.btn_start_tracking.setObjectName("btn_start_tracking")
        self.verticalLayout_15.addWidget(self.btn_start_tracking)
        self.widget_start_stop.addWidget(self.page)
        self.page_2 = QtWidgets.QWidget()
        self.page_2.setObjectName("page_2")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.page_2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.btn_stop_tracking = QtWidgets.QPushButton(self.page_2)
        self.btn_stop_tracking.setMinimumSize(QtCore.QSize(50, 50))
        self.btn_stop_tracking.setMaximumSize(QtCore.QSize(50, 50))
        self.btn_stop_tracking.setStyleSheet("background-color: rgb(255, 255, 255);\n"
"border: 1px solid black;\n"
"border-radius: 5px;")
        self.btn_stop_tracking.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap("../ast_monitor/icons/stop.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btn_stop_tracking.setIcon(icon4)
        self.btn_stop_tracking.setIconSize(QtCore.QSize(25, 25))
        self.btn_stop_tracking.setObjectName("btn_stop_tracking")
        self.verticalLayout.addWidget(self.btn_stop_tracking)
        self.widget_start_stop.addWidget(self.page_2)
        self.horizontalLayout_7.addWidget(self.widget_start_stop)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem9)
        self.verticalLayout_22.addLayout(self.horizontalLayout_7)
        self.verticalLayout_23.addWidget(self.widget_15)
        self.verticalLayout_24.addLayout(self.verticalLayout_23)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setEnabled(True)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 800, 0))
        self.menubar.setMaximumSize(QtCore.QSize(16777215, 0))
        self.menubar.setObjectName("menubar")
        self.menuMenu = QtWidgets.QMenu(self.menubar)
        self.menuMenu.setObjectName("menuMenu")
        self.menuAbout = QtWidgets.QMenu(self.menubar)
        self.menuAbout.setObjectName("menuAbout")
        MainWindow.setMenuBar(self.menubar)
        self.actionOpen = QtWidgets.QAction(MainWindow)
        self.actionOpen.setObjectName("actionOpen")
        self.actionSave = QtWidgets.QAction(MainWindow)
        self.actionSave.setObjectName("actionSave")
        self.action_exit = QtWidgets.QAction(MainWindow)
        self.action_exit.setObjectName("action_exit")
        self.action_license = QtWidgets.QAction(MainWindow)
        self.action_license.setObjectName("action_license")
        self.action_about_program = QtWidgets.QAction(MainWindow)
        self.action_about_program.setObjectName("action_about_program")
        self.action_disclaimer = QtWidgets.QAction(MainWindow)
        self.action_disclaimer.setObjectName("action_disclaimer")
        self.menuMenu.addAction(self.action_exit)
        self.menuAbout.addAction(self.action_about_program)
        self.menuAbout.addAction(self.action_license)
        self.menuAbout.addAction(self.action_disclaimer)
        self.menubar.addAction(self.menuMenu.menuAction())
        self.menubar.addAction(self.menuAbout.menuAction())

        self.retranslateUi(MainWindow)
        self.widget_title.setCurrentIndex(0)
        self.stackedWidget.setCurrentIndex(0)
        self.swgt_interval_performance.setCurrentIndex(0)
        self.widget_training_data.setCurrentIndex(0)
        self.stackedWidget_2.setCurrentIndex(0)
        self.widget_start_stop.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "TrainingFeedback"))
        self.lbl_page.setText(_translate("MainWindow", "Basic data"))
        self.lbl_page_2.setText(_translate("MainWindow", "Map"))
        self.lbl_page_3.setText(_translate("MainWindow", "Intervals"))
        self.lbl_page_4.setText(_translate("MainWindow", "Training"))
        self.lbl_distance.setText(_translate("MainWindow", "-"))
        self.lbl_speed.setText(_translate("MainWindow", "-"))
        self.lbl_heart_rate.setText(_translate("MainWindow", "-"))
        self.lbl_ascent.setText(_translate("MainWindow", "-"))
        self.lbl_watch.setText(_translate("MainWindow", "-"))
        self.label_2.setText(_translate("MainWindow", "AVG"))
        self.lbl_interval_average_heart_rate.setText(_translate("MainWindow", "-"))
        self.label_3.setText(_translate("MainWindow", "PROP"))
        self.lbl_interval_proposed_heart_rate.setText(_translate("MainWindow", "-"))
        self.lbl_interval_performance.setText(_translate("MainWindow", "Performance"))
        self.lbl_interval_performance_up.setText(_translate("MainWindow", "-"))
        self.lbl_interval_performance_down.setText(_translate("MainWindow", "-"))
        self.label.setText(_translate("MainWindow", "CUR"))
        self.lbl_interval_heart_rate.setText(_translate("MainWindow", "-"))
        self.lbl_interval_watch.setText(_translate("MainWindow", "0:00:00"))
        self.lbl_no_training.setText(_translate("MainWindow", "Currently, no training is loaded."))
        self.lbl_training_file.setText(_translate("MainWindow", "Title"))
        self.lbl_training_type.setText(_translate("MainWindow", "-"))
        self.lbl_training_speed_hr.setText(_translate("MainWindow", "-"))
        self.lbl_training_speed_hr_title.setText(_translate("MainWindow", "Speed heart rate:"))
        self.lbl_training_rest_duration_title.setText(_translate("MainWindow", "Rest duration:"))
        self.lbl_training_rest_duration.setText(_translate("MainWindow", "-"))
        self.lbl_training_type_title.setText(_translate("MainWindow", "Type:"))
        self.lbl_training_speed_duration_title.setText(_translate("MainWindow", "Speed duration:"))
        self.lbl_training_speed_duration.setText(_translate("MainWindow", "-"))
        self.lbl_training_rest_hr_title.setText(_translate("MainWindow", "Rest heart rate:"))
        self.lbl_training_repetitions_title.setText(_translate("MainWindow", "Repetitions:"))
        self.lbl_training_rest_hr.setText(_translate("MainWindow", "-"))
        self.lbl_training_repetitions.setText(_translate("MainWindow", "-"))
        self.btn_load_training.setText(_translate("MainWindow", "Load"))
        self.btn_start_training.setText(_translate("MainWindow", "Start"))
        self.menuMenu.setTitle(_translate("MainWindow", "Menu"))
        self.menuAbout.setTitle(_translate("MainWindow", "About"))
        self.actionOpen.setText(_translate("MainWindow", "Open"))
        self.actionSave.setText(_translate("MainWindow", "Save"))
        self.action_exit.setText(_translate("MainWindow", "Exit"))
        self.action_license.setText(_translate("MainWindow", "License"))
        self.action_about_program.setText(_translate("MainWindow", "About program"))
        self.action_disclaimer.setText(_translate("MainWindow", "Disclaimer"))
